#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

""" Tests for notification server"""
from typing import List

import pytest
from pyramid.config import Configurator
from pyramid.interfaces import IRoutesMapper


class TestNotificationServer:

    RouteList = List[str]

    @pytest.fixture()
    def notification_routes(self) -> RouteList:
        return [
            "home",
            "notifications",
            "notification",
            "send_notification",
            "healthcheck",
        ]

    def test_routes_exist(self, test_config: Configurator, notification_routes: RouteList):
        """
        Test that the pyramid config has the proper notification routes in place
        :param test_config: Mock pyramid config for testing
        :param notification_routes: List of expected routes
        """
        test_config.include("notification.routes")
        mapper = test_config.registry.queryUtility(IRoutesMapper)
        route_names = [route.name for route in mapper.get_routes()]
        assert notification_routes == route_names
