# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add carta workflow

Revision ID: 113e96b85a70
Revises: 1d653467ede6
Create Date: 2021-08-10 07:56:55.912194

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "113e96b85a70"
down_revision = "1d653467ede6"
branch_labels = None
depends_on = None


condor_content = """executable = carta.sh
arguments = {{source_directory}} {{image_list}}

output = carta.out
error = carta.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/carta_envoy

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

script_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

cd $1
{{#needData}}
./productfectcher $2 &
{{/needData}}
./carta_envoy -w $1 &

"""


def upgrade():
    op.execute(
        """
        INSERT INTO workflows (workflow_name) VALUES ('carta')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('carta.condor', E'{condor_content}', 'carta')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('carta.sh', E'{script_content}', 'carta')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflows WHERE workflow_name='carta'
        """
    )
    op.execute(
        """
        DELETE FROM workflow_templates WHERE workflow_name='carta'
        """
    )
